@@ -1,9 +1,9 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 #include <nan.h>
@@ -12,14 +12,20 @@
 
 using v8::Function;
 using v8::Local;
-using v8::Null;
 using v8::Number;
 using v8::Value;
+using Nan::AsyncQueueWorker;
+using Nan::AsyncWorker;
+using Nan::Callback;
+using Nan::HandleScope;
+using Nan::New;
+using Nan::Null;
+using Nan::To;
 
-class PiWorker : public NanAsyncWorker {
+class PiWorker : public AsyncWorker {
  public:
-  PiWorker(NanCallback *callback, int points)
-    : NanAsyncWorker(callback), points(points), estimate(0) {}
+  PiWorker(Callback *callback, int points)
+    : AsyncWorker(callback), points(points), estimate(0) {}
   ~PiWorker() {}
 
   // Executed inside the worker-thread.
@@ -34,11 +40,11 @@ class PiWorker : public NanAsyncWorker {
   // this function will be run inside the main event loop
   // so it is safe to use V8 again
   void HandleOKCallback () {
-    NanScope();
+    HandleScope scope;
 
     Local<Value> argv[] = {
-        NanNull()
-      , NanNew<Number>(estimate)
+        Null()
+      , New<Number>(estimate)
     };
 
     callback->Call(2, argv);
@@ -51,11 +57,8 @@ class PiWorker : public NanAsyncWorker {
 
 // Asynchronous access to the `Estimate()` function
 NAN_METHOD(CalculateAsync) {
-  NanScope();
+  int points = To<int>(info[0]).FromJust();
+  Callback *callback = new Callback(info[1].As<Function>());
 
-  int points = args[0]->Uint32Value();
-  NanCallback *callback = new NanCallback(args[1].As<Function>());
-
-  NanAsyncQueueWorker(new PiWorker(callback, points));
-  NanReturnUndefined();
+  AsyncQueueWorker(new PiWorker(callback, points));
 }
