@@ -30,6 +30,8 @@ MyObject::MyObject() {
 MyObject::~MyObject() {
 }
 
+void Foo(FunctionCallbackInfo<v8::Value> const&) {}
+
 NAN_MODULE_INIT(MyObject::Init) {
   // Prepare constructor template
   v8::Local<v8::FunctionTemplate> tpl = Nan::New<v8::FunctionTemplate>(New);
@@ -74,6 +76,19 @@ NAN_MODULE_INIT(MyObject::Init) {
   Set(target
   , Nan::New<v8::String>("MyObject").ToLocalChecked()
   , tpl->GetFunction());
+
+
+  //=== SetMethod ==============================================================
+
+  v8::Local<v8::Object> obj = Nan::New<v8::Object>();
+  SetMethod(obj, "foo", Foo);
+
+  // https://github.com/nodejs/nan/issues/564
+  v8::Local<v8::Function> func = Nan::New<v8::Function>(Foo);
+  SetMethod(func, "foo", Foo);
+
+  v8::Local<v8::FunctionTemplate> t = Nan::New<v8::FunctionTemplate>(Foo);
+  SetMethod(t, "foo", Foo);
 }
 
 NAN_METHOD(MyObject::New) {
