@@ -11,15 +11,17 @@ const test     = require('tap').test
     , bindings = require('bindings')({ module_root: testRoot, bindings: 'objectwraphandle' });
 
 test('objectwraphandle', function (t) {
-  t.plan(7);
+  t.plan(9);
 
   t.type(bindings.MyObject, 'function');
 
   var obj = new bindings.MyObject(10);
 
   t.type(obj.getHandle, 'function');
+  t.type(obj.getHandleConst, 'function');
   t.type(obj.getValue, 'function');
   t.type(obj.getHandle(), 'object');
+  t.type(obj.getHandleConst(), 'object');
   t.type(obj.getValue(), 'number');
 
   var derived = Object.create(obj);
